@@ -1,6 +1,6 @@
 from typing import Dict, Optional
 
-from mindee.documents.base import Document
+from mindee.documents.base import Document, TypeApiPrediction
 
 
 class CustomDocument(Document):
@@ -10,7 +10,7 @@ class CustomDocument(Document):
     def __init__(
         self,
         document_type: str,
-        api_prediction=None,
+        api_prediction: TypeApiPrediction,
         input_file=None,
         page_n: Optional[int] = None,
     ):
@@ -30,8 +30,8 @@ class CustomDocument(Document):
         )
 
     def _build_from_api_prediction(
-        self, api_prediction: dict, page_n: Optional[int] = None
-    ):
+        self, api_prediction: TypeApiPrediction, page_n: Optional[int] = None
+    ) -> None:
         """
         Build the document from an API response JSON.
 
@@ -49,9 +49,9 @@ class CustomDocument(Document):
         for name, info in self.fields.items():
             custom_doc_str += "%s: %s\n" % (
                 name,
-                "".join([value["content"] for value in info["values"]]),
+                " ".join([value["content"] for value in info["values"]]),
             )
-        custom_doc_str += "-----------------\n"
+        custom_doc_str += "----------------------"
         return custom_doc_str
 
     def _checklist(self) -> None:
