@@ -1,8 +1,9 @@
 from typing import List, Optional
 
-from mindee.documents.base import Document
+from mindee.documents.base import Document, TypeApiPrediction
 from mindee.documents.invoice import Invoice
 from mindee.documents.receipt import Receipt
+from mindee.endpoints import Endpoint
 from mindee.fields.amount import Amount
 from mindee.fields.base import Field, TypedField
 from mindee.fields.date import Date
@@ -10,7 +11,6 @@ from mindee.fields.locale import Locale
 from mindee.fields.orientation import Orientation
 from mindee.fields.payment_details import PaymentDetails
 from mindee.fields.tax import Tax
-from mindee.http import Endpoint
 
 
 class FinancialDocument(Document):
@@ -76,8 +76,8 @@ class FinancialDocument(Document):
         )
 
     def _build_from_api_prediction(
-        self, api_prediction: dict, page_n: Optional[int] = None
-    ):
+        self, api_prediction: TypeApiPrediction, page_n: Optional[int] = None
+    ) -> None:
         """
         Build the document from an API response JSON.
 
