@@ -1,7 +1,7 @@
 from datetime import datetime
 from typing import List, Optional
 
-from mindee.documents.base import Document
+from mindee.documents.base import Document, TypeApiPrediction
 from mindee.fields.base import Field, field_array_confidence
 from mindee.fields.date import Date
 
@@ -59,8 +59,8 @@ class Passport(Document):
         )
 
     def _build_from_api_prediction(
-        self, api_prediction: dict, page_n: Optional[int] = None
-    ):
+        self, api_prediction: TypeApiPrediction, page_n: Optional[int] = None
+    ) -> None:
         """
         Build the document from an API response JSON.
 
@@ -117,7 +117,7 @@ class Passport(Document):
         :return: True if the passport is expired, False otherwise
         """
         if not self.expiry_date.date_object:
-            return False
+            return True
         return self.expiry_date.date_object < datetime.date(datetime.now())
 
     def _reconstruct(self) -> None:
@@ -133,23 +133,9 @@ class Passport(Document):
             "mrz_expiration_date_checksum": self.__mrz_expiration_date_checksum(),
             "mrz_personal_number_checksum": self.__mrz_personal_number_checksum(),
             "mrz_last_name_checksum": self.__mrz_last_name_checksum(),
-            "mrz_checksum": self.__mrz__checksum(),
         }
 
     # Checks
-    def __mrz__checksum(self) -> bool:
-        """
-        Validate all MRZ checksums.
-
-        :return: True if all are valid, False otherwise
-        """
-        return (
-            self.__mrz_id_number_checksum()
-            and self.__mrz_date_of_birth_checksum()
-            and self.__mrz_expiration_date_checksum()
-            and self.__mrz_personal_number_checksum()
-            and self.__mrz_last_name_checksum()
-        )
 
     def __mrz_id_number_checksum(self) -> bool:
         """
