@@ -11,7 +11,7 @@ class Amount(Field):
         amount_prediction: dict,
         value_key: str = "amount",
         reconstructed: bool = False,
-        page_n=None,
+        page_n: Optional[int] = None,
     ):
         """
         Amount field object.
@@ -19,7 +19,7 @@ class Amount(Field):
         :param amount_prediction: Amount prediction object from HTTP response
         :param value_key: Key to use in the amount_prediction dict
         :param reconstructed: Bool for reconstructed object (not extracted in the API)
-        :param page_n: Page number for multi pages pdf
+        :param page_n: Page number for multi-page PDF
         """
         super().__init__(
             amount_prediction,
