@@ -22,7 +22,7 @@ class PaymentDetails(Field):
         routing_number_key: str = "routing_number",
         swift_key: str = "swift",
         reconstructed: bool = False,
-        page_n=None,
+        page_n: Optional[int] = None,
     ):
         """
         Payment details field object.
@@ -36,7 +36,7 @@ class PaymentDetails(Field):
             payment_details_prediction dict
         :param swift_key: Key to use for getting the SWIFT  in the payment_details_prediction dict
         :param reconstructed: Bool for reconstructed object (not extracted in the API)
-        :param page_n: Page number for multi pages pdf
+        :param page_n: Page number for multi-page PDF
         """
         super().__init__(
             payment_details_prediction,
@@ -78,13 +78,13 @@ class PaymentDetails(Field):
             self.swift = None
 
     def __str__(self) -> str:
-        output_str = ""
+        out_str = ""
         if self.account_number is not None:
-            output_str += str(self.account_number) + "; "
+            out_str += str(self.account_number) + "; "
         if self.iban is not None:
-            output_str += str(self.iban) + "; "
+            out_str += str(self.iban) + "; "
         if self.routing_number is not None:
-            output_str += str(self.routing_number) + "; "
+            out_str += str(self.routing_number) + "; "
         if self.swift is not None:
-            output_str += str(self.swift) + "; "
-        return output_str.strip()
+            out_str += str(self.swift) + "; "
+        return out_str.strip()
