@@ -1,19 +1,24 @@
 import base64
 import io
+import mimetypes
 import os
-from mimetypes import guess_type
 from typing import BinaryIO, Optional, Tuple
 
 import pikepdf
 
 from mindee.logger import logger
 
+mimetypes.add_type("image/heic", ".heic")
+mimetypes.add_type("image/heic", ".heif")
+
 ALLOWED_MIME_TYPES = [
+    "application/pdf",
+    "image/heic",
     "image/png",
     "image/jpg",
     "image/jpeg",
+    "image/tiff",
     "image/webp",
-    "application/pdf",
 ]
 
 INPUT_TYPE_FILE = "file"
@@ -21,6 +26,8 @@ INPUT_TYPE_BASE64 = "base64"
 INPUT_TYPE_BYTES = "bytes"
 INPUT_TYPE_PATH = "path"
 
+MAX_DOC_PAGES = 3
+
 
 class InputDocument:
     file_object: BinaryIO
@@ -34,10 +41,10 @@ class InputDocument:
     def __init__(
         self,
         input_type: str,
-        cut_pdf=True,
-        n_pdf_pages=3,
+        cut_pdf: bool = True,
+        n_pdf_pages: int = MAX_DOC_PAGES,
     ):
-        assert 0 < n_pdf_pages <= 3
+        assert 0 < n_pdf_pages <= MAX_DOC_PAGES
         self.input_type = input_type
         self._check_mimetype()
 
@@ -45,7 +52,7 @@ class InputDocument:
             self.check_pdf_open()
             count_pages = self.count_pdf_pages()
             if cut_pdf is True:
-                if count_pages > 3:
+                if count_pages > MAX_DOC_PAGES:
                     self.merge_pdf_pages(
                         [0, count_pages - 2, count_pages - 1][:n_pdf_pages]
                     )
@@ -54,7 +61,7 @@ class InputDocument:
         logger.debug("Loaded new document '%s' from %s", self.filename, self.input_type)
 
     def _check_mimetype(self) -> None:
-        file_mimetype = guess_type(self.filename)[0]
+        file_mimetype = mimetypes.guess_type(self.filename)[0]
         if file_mimetype:
             self.file_mimetype = file_mimetype
         else:
@@ -152,8 +159,8 @@ class FileDocument(InputDocument):
     def __init__(
         self,
         file: BinaryIO,
-        cut_pdf=True,
-        n_pdf_pages=3,
+        cut_pdf: bool = True,
+        n_pdf_pages: int = 3,
     ):
         """
         Input document from a Python binary file object.
@@ -180,8 +187,8 @@ class PathDocument(InputDocument):
     def __init__(
         self,
         filepath: str,
-        cut_pdf=True,
-        n_pdf_pages=3,
+        cut_pdf: bool = True,
+        n_pdf_pages: int = 3,
     ):
         """
         Input document from a path.
@@ -205,8 +212,8 @@ class BytesDocument(InputDocument):
         self,
         raw_bytes: bytes,
         filename: str,
-        cut_pdf=True,
-        n_pdf_pages=3,
+        cut_pdf: bool = True,
+        n_pdf_pages: int = 3,
     ):
         """
         Input document from raw bytes (no buffer).
@@ -232,8 +239,8 @@ class Base64Document(InputDocument):
         self,
         base64_string: str,
         filename: str,
-        cut_pdf=True,
-        n_pdf_pages=3,
+        cut_pdf: bool = True,
+        n_pdf_pages: int = 3,
     ):
         """
         Input document from a base64 encoded string.
