@@ -34,7 +34,7 @@ class DocumentResponse:
 
 
 def format_response(
-    doc_config: DocumentConfig, http_response: dict, document_type: str, input_file
+    doc_config: DocumentConfig, http_response: dict, input_file
 ) -> DocumentResponse:
     """
     Create a `DocumentResponse`.
@@ -42,10 +42,9 @@ def format_response(
     :param doc_config: DocumentConfig
     :param input_file: Input object
     :param http_response: json response from HTTP call
-    :param document_type: Document class
     :return: Full DocumentResponse object
     """
-    http_response["document_type"] = document_type
+    http_response["document_type"] = doc_config.document_type
     http_response["input_type"] = input_file.input_type
     http_response["filename"] = input_file.filename
     http_response["filepath"] = input_file.filepath
@@ -61,20 +60,20 @@ def format_response(
                 api_prediction=page_prediction["prediction"],
                 input_file=input_file,
                 page_n=page_prediction["id"],
-                document_type=document_type,
+                document_type=doc_config.document_type,
             )
         )
     # Create the document level object
     document_level = doc_config.constructor(
         api_prediction=http_response["document"]["inference"]["prediction"],
         input_file=input_file,
-        document_type=document_type,
+        document_type=doc_config.document_type,
         page_n=None,
     )
     return DocumentResponse(
         doc_config,
         http_response=http_response,
         pages=pages,
-        document_type=document_type,
+        document_type=doc_config.document_type,
         document=document_level,
     )
