@@ -3,7 +3,7 @@ from argparse import Namespace
 import pytest
 
 from mindee.__main__ import call_endpoint
-from mindee.http import HTTPException
+from mindee.endpoints import HTTPException
 from tests.utils import clear_envvars
 
 
@@ -33,7 +33,7 @@ def ots_doc(monkeypatch):
         input_type="path",
         output_type="summary",
         include_words=False,
-        path="./tests/data/invoices/invoice.pdf",
+        path="./tests/data/invoice/invoice.pdf",
     )
 
 
